@@ -163,7 +163,7 @@ set_silent(model)
 @variable(model, y[1:n, 1:n] >= 0)
 @constraint(model, sum(x) <= 11)
 @constraint(model, [i = 1:n, j = 1:n], y[i, j] <= G[i, j] * x[i, j])
-@constraint(model, [i = 2:n-1], sum(y[i, :]) == sum(y[:, i]))
+@constraint(model, [i = 2:(n-1)], sum(y[i, :]) == sum(y[:, i]))
 @objective(model, Min, 0.1 * sum(x) - sum(y[1, :]))
 optimize!(model)
 assert_is_solved_and_feasible(model)  #src
@@ -215,7 +215,7 @@ function solve_subproblem(x_bar)
     @variable(model, x[i in 1:n, j in 1:n] == x_bar[i, j])
     @variable(model, y[1:n, 1:n] >= 0)
     @constraint(model, [i = 1:n, j = 1:n], y[i, j] <= G[i, j] * x[i, j])
-    @constraint(model, [i = 2:n-1], sum(y[i, :]) == sum(y[:, i]))
+    @constraint(model, [i = 2:(n-1)], sum(y[i, :]) == sum(y[:, i]))
     @objective(model, Min, -sum(y[1, :]))
     optimize!(model)
     assert_is_solved_and_feasible(model; dual = true)
@@ -385,7 +385,7 @@ set_silent(subproblem)
 @variable(subproblem, x_copy[i in 1:n, j in 1:n])
 @variable(subproblem, y[1:n, 1:n] >= 0)
 @constraint(subproblem, [i = 1:n, j = 1:n], y[i, j] <= G[i, j] * x_copy[i, j])
-@constraint(subproblem, [i = 2:n-1], sum(y[i, :]) == sum(y[:, i]))
+@constraint(subproblem, [i = 2:(n-1)], sum(y[i, :]) == sum(y[:, i]))
 @objective(subproblem, Min, -sum(y[1, :]))
 subproblem
 
@@ -473,7 +473,7 @@ set_attribute(subproblem, "presolve", "off")
 @variable(subproblem, y[1:n, 1:n] >= 0)
 @constraint(subproblem, sum(y) >= 1)  # <--- THIS IS NEW
 @constraint(subproblem, [i = 1:n, j = 1:n], y[i, j] <= G[i, j] * x_copy[i, j])
-@constraint(subproblem, [i = 2:n-1], sum(y[i, :]) == sum(y[:, i]))
+@constraint(subproblem, [i = 2:(n-1)], sum(y[i, :]) == sum(y[:, i]))
 @objective(subproblem, Min, -sum(y[1, :]))
 subproblem
 
