@@ -990,4 +990,17 @@ function test_issue_4053()
     return
 end
 
+function test_sum_init()
+    x = Containers.@container([i in Int[]], i)
+    @test sum(x) == 0
+    @test sum(x; init = 1) == 1
+    y = Containers.@container([i in BigInt[]], i)
+    y_1 = sum(y)
+    @test y_1 == 0
+    @test y_1 isa BigInt
+    y_2 = sum(y; init = 0)
+    @test y_2 === 0
+    return
+end
+
 end  # module
